/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "project.h"
#include "stdio.h"

#define MaxCount            4095     //(counts)
#define Vref                1.026      //(Volts)
#define Fsw                 3000000  //(Hz)
#define IDAC_VALUE          16
#define IDAC_Conversion     0.0000024 //(A/bit)
#define femto               1000000000000000
#define BUFFER_SIZE         (0x02u)
#define CapAddress          0x08
#define RawAddress          0x09

int GetAverageRawCount(void);

int GetCapacitanceValue(int raw, double Imod);

void Print(int capacitance, int rawAverage, int APIcapacitance, int uImod);

void fillBuffer(int data1, int data2);

void write2BLE(uint8 addr, uint8 buffer[]);

uint8 wrData1[BUFFER_SIZE], wrData2[BUFFER_SIZE];

int main(void)

{
    CyGlobalIntEnable; /* Enable global interrupts. */

    int capacitance, APIcapacitance, uImod, rawAverage;
    double Imod = IDAC_Conversion *  9; //IDAC_VALUE;
    uImod = (int)(Imod * 1000000);
    
    /* Change SCL and SDA pins drive mode to Resistive Pull Up */
    i2c_scl_SetDriveMode(i2c_scl_DM_RES_UP);
    i2c_sda_SetDriveMode(i2c_sda_DM_RES_UP);

    /* Start the CapSense, I2C, and UART components */
    UART_Start();
    
	i2c_Start();
   
    CapSense_Start();
    
    UART_UartPutString("\r\nSensor Capacitance and Other Parameters\r\n");
    
    /* Scan all the CapSense widgets */

    CapSense_ScanAllWidgets();
    
    

     

      for(;;)

      {

        /* Check if CapSense scan is completed*/

        if (!CapSense_IsBusy())

        {

            /* Process all the CapSense widgets */

            CapSense_ProcessAllWidgets();
            
            /*Get Average Raw Count Data*/
            rawAverage = GetAverageRawCount();
            
            /* Get Sensor Parasitic Capacitance Through API */
            APIcapacitance = CapSense_GetSensorCapacitance(CapSense_BUTTON0_WDGT_ID, CapSense_BUTTON0_SNS0_ID);
            
            capacitance = GetCapacitanceValue(rawAverage, Imod);
            
            /*fill the i2c data buffers*/
            fillBuffer(capacitance, rawAverage);
         //   for(uint8 i = 0; i < 5; ++i){
           // wrData1[i] = 42;
            //wrData2[i] = 42;
            //}
            /*write data to BLE module*/
            write2BLE(CapAddress, wrData1);
            write2BLE(RawAddress, wrData2);
            
            
            /*print data to terminal via UART*/
            Print(capacitance, rawAverage, APIcapacitance, uImod);
            
            
            
            /* Delay for 1s */
            CyDelay(1000);
            
            /* Scan all the CapSense widgets*/ 

            CapSense_ScanAllWidgets();

        }

      }

}

int GetAverageRawCount(void){
    /* Get an average of 30 Raw Count values*/
            
    int rawAverage = 0;
    uint32 raw_count;
    for(uint8 i = 0; i < 30; ++i){
                
    CapSense_GetParam (CapSense_BUTTON0_SNS0_RAW0_PARAM_ID , &raw_count);
    rawAverage = rawAverage + (raw_count / 30);
                
    }
    return rawAverage;
}

int GetCapacitanceValue(int raw, double Imod){
    /* calculate sensor capacitance using average rawcount data */
    int capacitance;
    capacitance = femto * (raw + MaxCount) * Imod / (MaxCount * Vref * Fsw);
    return capacitance;
}

void Print(int capacitance, int rawAverage, int APIcapacitance, int uImod){
    /* Convert Capacitance Value to ASCII */
            char MyString1[50], MyString2[50], MyString3[50], MyString4[50]; 
            
            sprintf(MyString3, "%d", capacitance);
            sprintf(MyString1, "%d", rawAverage);
            sprintf(MyString2, "%d", APIcapacitance);
            sprintf(MyString4, "%d", uImod);
            
            
            UART_UartPutString(MyString1);
            UART_UartPutString(" counts\r\n");
            UART_UartPutString(MyString2);
            UART_UartPutString(" pF\r\n");
            UART_UartPutString(MyString3);
            UART_UartPutString(" fF\r\n");
            UART_UartPutString(MyString4);
            UART_UartPutString(" uA\r\n");
            
}
void fillBuffer(int data1, int data2){
    
   
    for(uint8 i =  0; i < BUFFER_SIZE; ++i){
        wrData1[i] = (data1 & 0b1111111100000000) >> 8;
        wrData2[i] = (data2 & 0b1111111100000000) >> 8;
        if(i < 1){
           data1 = data1 << 8;
           data2 = data2 << 8;
        }
        
    }

}

void write2BLE(uint8 addr, uint8 buffer[]){
    /* clear any previous states */
		 i2c_I2CMasterClearStatus(); 
		 i2c_I2CMasterWriteBuf(addr, (uint8 *) buffer, BUFFER_SIZE, i2c_I2C_MODE_COMPLETE_XFER);
		  while(0u == (i2c_I2CMasterStatus() & i2c_I2C_MSTAT_WR_CMPLT)) continue;
}